"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault").default;
exports.__esModule = true;
exports.isRelativeJsonPointer = exports.default = void 0;
var _apidomJsonPointer = require("@swagger-api/apidom-json-pointer");
var _InvalidRelativeJsonPointerError = _interopRequireDefault(require("./errors/InvalidRelativeJsonPointerError.cjs"));
const nonNegativeIntegerPrefixRegExp = '(?<nonNegativeIntegerPrefix>[1-9]\\d*|0)';
const indexManipulationRegExp = '(?<indexManipulation>[+-][1-9]\\d*|0)';
const hashCharacterRegExp = '(?<hashCharacter>#)';
const jsonPointerRegExp = '(?<jsonPointer>\\/.*)';
const relativeJsonPointerRegExp = new RegExp(`^${nonNegativeIntegerPrefixRegExp}${indexManipulationRegExp}?(${hashCharacterRegExp}|${jsonPointerRegExp})?$`);

/**
 * @public
 */
const isRelativeJsonPointer = value => {
  return typeof value === 'string' && relativeJsonPointerRegExp.test(value);
};

/**
 * @public
 */
exports.isRelativeJsonPointer = isRelativeJsonPointer;
const parse = relativePointer => {
  const match = relativePointer.match(relativeJsonPointerRegExp);
  if (match === null || typeof match.groups === 'undefined') {
    throw new _InvalidRelativeJsonPointerError.default(`Invalid Relative JSON Pointer "${relativePointer}".`, {
      relativePointer
    });
  }
  try {
    // non-negative-integer
    const nonNegativeIntegerPrefix = parseInt(match.groups.nonNegativeIntegerPrefix, 10);
    // index-manipulation
    const indexManipulation = typeof match.groups.indexManipulation === 'string' ? parseInt(match.groups.indexManipulation, 10) : undefined;
    // <json-pointer>
    const jsonPointerTokens = typeof match.groups.jsonPointer === 'string' ? (0, _apidomJsonPointer.parse)(match.groups.jsonPointer) : undefined;
    // "#"
    const hashCharacter = typeof match.groups.hashCharacter === 'string';
    return {
      nonNegativeIntegerPrefix,
      indexManipulation,
      jsonPointerTokens,
      hashCharacter
    };
  } catch (error) {
    throw new _InvalidRelativeJsonPointerError.default(`Relative JSON Pointer parsing of "${relativePointer}" encountered an error.`, {
      relativePointer,
      cause: error
    });
  }
};
var _default = exports.default = parse;